## Cepa (Python Tor Library)

 _Cepa (short for [allium cepa](https://www.sciencedirect.com/topics/agricultural-and-biological-sciences/allium-cepa)) is a fork of stem that adds support for v3 onion client authentication._

Stem is a Python controller library for **[Tor](https://www.torproject.org/)**. With it you can use Tor's [control protocol](https://gitweb.torproject.org/torspec.git/tree/control-spec.txt) to script against the Tor process, or build things such as [Nyx](https://nyx.torproject.org/).

Documentation and tutorials available at **[stem.torproject.org](https://stem.torproject.org/)**.
